import { Context } from "./context";
import * as Inputs from "./inputs";
import { DrawHelperCore } from "@bitbybit-dev/core";
import { JSCADText } from "@bitbybit-dev/jscad-worker";
import { Vector } from "@bitbybit-dev/base";
import { JSCADWorkerManager } from "@bitbybit-dev/jscad-worker";
import { ManifoldWorkerManager } from "@bitbybit-dev/manifold-worker";
import { OCCTWorkerManager } from "@bitbybit-dev/occt-worker";
import { Group, MeshPhysicalMaterial } from "three";
export declare class DrawHelper extends DrawHelperCore {
    private readonly context;
    private readonly solidText;
    readonly vector: Vector;
    private readonly jscadWorkerManager;
    private readonly manifoldWorkerManager;
    private readonly occWorkerManager;
    private usedMaterials;
    constructor(context: Context, solidText: JSCADText, vector: Vector, jscadWorkerManager: JSCADWorkerManager, manifoldWorkerManager: ManifoldWorkerManager, occWorkerManager: OCCTWorkerManager);
    drawManifoldsOrCrossSections(inputs: Inputs.Manifold.DrawManifoldsOrCrossSectionsDto<Inputs.Manifold.ManifoldPointer | Inputs.Manifold.CrossSectionPointer, MeshPhysicalMaterial>): Promise<Group>;
    drawManifoldOrCrossSection(inputs: Inputs.Manifold.DrawManifoldOrCrossSectionDto<Inputs.Manifold.ManifoldPointer | Inputs.Manifold.CrossSectionPointer, MeshPhysicalMaterial>): Promise<Group>;
    drawShape(inputs: Inputs.OCCT.DrawShapeDto<Inputs.OCCT.TopoDSShapePointer>): Promise<Group>;
    drawShapes(inputs: Inputs.OCCT.DrawShapesDto<Inputs.OCCT.TopoDSShapePointer>): Promise<Group>;
    drawSolidOrPolygonMesh(inputs: Inputs.JSCAD.DrawSolidMeshDto<Group>): Promise<Group>;
    drawSolidOrPolygonMeshes(inputs: Inputs.JSCAD.DrawSolidMeshesDto<Group>): Promise<Group>;
    drawPolylinesWithColours(inputs: Inputs.Polyline.DrawPolylinesDto<Group>): Group<import("three").Object3DEventMap>;
    drawPoint(inputs: Inputs.Point.DrawPointDto<Group>): Group;
    drawPolylineClose(inputs: Inputs.Polyline.DrawPolylineDto<Group>): Group;
    drawPolyline(mesh: Group, pointsToDraw: Inputs.Base.Point3[], updatable: boolean, size: number, opacity: number, colours: string | string[]): Group;
    drawCurve(inputs: Inputs.Verb.DrawCurveDto<Group>): Group;
    drawPoints(inputs: Inputs.Point.DrawPointsDto<Group>): Group;
    updatePointsInstances(group: Group, positions: Inputs.Base.Point3[]): void;
    drawCurves(inputs: Inputs.Verb.DrawCurvesDto<Group>): Group;
    drawSurfacesMultiColour(inputs: Inputs.Verb.DrawSurfacesColoursDto<Group>): Group;
    private createPointSpheresMesh;
    createOrUpdateSurfacesMesh(meshDataConverted: {
        positions: number[];
        indices: number[];
        normals: number[];
        uvs?: number[];
    }[], group: Group, updatable: boolean, material: MeshPhysicalMaterial, addToScene: boolean, hidden: boolean): Group;
    drawSurface(inputs: Inputs.Verb.DrawSurfaceDto<Group>): Group;
    private parseFaces;
    private makeMesh;
    private createMesh;
    private handleDecomposedMesh;
    private drawPolylines;
    private createLineGeometry;
    private handleDecomposedManifold;
}
